ColumnCommand class

Snapshot of a column mutation.

Annotations
  • @immutable

Constructors

ColumnCommand({required ColumnCommandKind kind, required String name, ColumnDefinition? definition})
const
ColumnCommand.fromJson(Map<String, Object?> json)
factory

Properties

definition → ColumnDefinition?
Column definition associated with the command, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → ColumnCommandKind
Command kind describing the mutation.
final
name → String
Column name targeted by the command.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited