ColumnDefault class

Representation of a default value. Literal values and SQL expressions are both supported.

Annotations
  • @immutable

Properties

expression → String?
SQL expression evaluated when inserting the column.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useCurrentTimestamp → bool
Whether to use the database current timestamp helper.
final
value → Object?
Literal value to use as default.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited