ForeignKeyCommand class

Snapshot of a foreign key mutation.

Annotations
  • @immutable

Properties

definition → ForeignKeyDefinition?
Optional foreign key definition provided for add commands.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → ForeignKeyCommandKind
Command kind describing foreign key add/drop.
final
name → String
Name of the foreign key affected by the command.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited