MigrationDescriptor class

Snapshot of a compiled migration ready to be logged inside the ledger.

Constructors

MigrationDescriptor({required MigrationId id, required SchemaPlan up, required SchemaPlan down, required String checksum})
MigrationDescriptor.fromJson(Map<String, Object?> json)
factory
MigrationDescriptor.fromMigration({required MigrationId id, required Migration migration, String? defaultSchema, String? tablePrefix})
factory

Properties

checksum → String
final
down → SchemaPlan
final
hashCode → int
The hash code for this object.
no setterinherited
id → MigrationId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
up → SchemaPlan
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited