MigrationStatus class

Status information for a migration when listing history.

Constructors

MigrationStatus({required MigrationDescriptor descriptor, required bool applied, DateTime? appliedAt, int? batch})
const

Properties

applied → bool
final
appliedAt → DateTime?
final
batch → int?
final
descriptor → MigrationDescriptor
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited