ModelColumnSnapshot class

Snapshot of a single column derived from a model field.

Constructors

ModelColumnSnapshot({required String name, required String columnName, required String resolvedType, required String? columnType, required bool isNullable, required bool isPrimaryKey, required bool isUnique, required bool isIndexed, required bool autoIncrement})

Properties

autoIncrement → bool
final
columnName → String
final
columnType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isIndexed → bool
final
isNullable → bool
final
isPrimaryKey → bool
final
isUnique → bool
final
name → String
final
resolvedType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

effectiveColumnType() → ColumnType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited