OrmMigrationRecordInsertDto class

Insert DTO for OrmMigrationRecord.

Auto-increment/DB-generated fields are omitted by default.

Constructors

OrmMigrationRecordInsertDto({String? id, String? checksum, DateTime? appliedAt, int? batch})
const

Properties

appliedAt → DateTime?
final
batch → int?
final
checksum → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? id = _copyWithSentinel, Object? checksum = _copyWithSentinel, Object? appliedAt = _copyWithSentinel, Object? batch = _copyWithSentinel}) → OrmMigrationRecordInsertDto
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
Converts this DTO to a map suitable for database insertion.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited