SchemaForeignKey class

Metadata describing a foreign key constraint.

Returned by SchemaDriver.listForeignKeys.

Constructors

SchemaForeignKey({required String name, required List<String> columns, required String referencedTable, required List<String> referencedColumns, String? tableName, String? schema, String? referencedSchema, String? onUpdate, String? onDelete})
const
SchemaForeignKey.fromJson(Map<String, Object?> json)
factory

Properties

columns → List<String>
Columns participating in the foreign key.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Constraint name.
final
onDelete → String?
Action taken when the referenced row deletes.
final
onUpdate → String?
Action taken when the referenced row updates.
final
referencedColumns → List<String>
Target columns that this foreign key references.
final
referencedSchema → String?
Schema containing the referenced table.
final
referencedTable → String
Target table that this foreign key references.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Schema that contains the foreign key.
final
tableName → String?
Table that owns the foreign key.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited