SchemaMutation class

A mutation emitted by the schema builder.

Constructors

SchemaMutation.alterTable(TableBlueprint blueprint)
factory
SchemaMutation.createCollection({required String collection, Map<String, Object?>? validator, Map<String, Object?>? options})
factory
SchemaMutation.createDatabase({required String name, Map<String, Object?>? options})
factory
SchemaMutation.createIndex({required String collection, required Map<String, Object?> keys, Map<String, Object?>? options})
factory
SchemaMutation.createTable(TableBlueprint blueprint)
factory
SchemaMutation.dropCollection({required String collection})
factory
SchemaMutation.dropDatabase({required String name, bool ifExists = false})
factory
SchemaMutation.dropIndex({required String collection, required String name})
factory
SchemaMutation.dropTable({required String table, bool ifExists = false, bool cascade = false})
factory
SchemaMutation.fromJson(Map<String, Object?> json)
factory
SchemaMutation.modifyValidator({required String collection, required Map<String, Object?> validator})
factory
SchemaMutation.rawSql(String sql, {List<Object?> parameters = const []})
factory
SchemaMutation.renameTable({required String from, required String to})
factory

Properties

blueprint → TableBlueprint?
final
documentPayload → Map<String, Object?>?
final
dropOptions → DropTableOptions?
final
hashCode → int
The hash code for this object.
no setterinherited
operation → SchemaMutationOperation
final
parameters → List<Object?>
final
rename → RenameTableOptions?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String?
final
table → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited