SchemaView class

Metadata describing a database view.

Returned by SchemaDriver.listViews.

Constructors

SchemaView({required String name, String? schema, String? definition})
const
SchemaView.fromJson(Map<String, Object?> json)
factory

Properties

definition → String?
SQL definition used to create the view.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
View name without schema qualification.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
Schema that contains the view, if provided.
final
schemaQualifiedName → String
Fully qualified name including schema when applicable.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited