SqliteFullTextOptions class

Options for SQLite full text search indexes.

Annotations
  • @immutable

Constructors

SqliteFullTextOptions({String? tokenizer, List<int> prefixSizes = const []})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasOptions → bool
no setter
prefixSizes → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenizer → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited