SqliteSpatialIndexOptions class

Options controlling SQLite spatial indexes.

Annotations
  • @immutable

Constructors

SqliteSpatialIndexOptions({List<String>? boundingColumns, bool maintainSync = true})
const

Properties

boundingColumns → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
hasOptions → bool
no setter
maintainSync → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited