recordsRawChanges property
Whether executeRaw should publish the SQL write it executes.
Adapters that wrap another executor and maintain their own transaction change scopes can override this and publish from their wrapper instead.
Implementation
bool get recordsRawChanges => true;